@@ -2,7 +2,7 @@
 /*!	\file import.cpp
 **	\brief Implementation of the "Import Image" layer
 **
-**	$Id: import.cpp 1191 2007-12-10 01:58:46Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -58,7 +58,7 @@ SYNFIG_LAYER_SET_NAME(Import,"import");
 SYNFIG_LAYER_SET_LOCAL_NAME(Import,N_("Import Image"));
 SYNFIG_LAYER_SET_CATEGORY(Import,N_("Other"));
 SYNFIG_LAYER_SET_VERSION(Import,"0.1");
-SYNFIG_LAYER_SET_CVS_ID(Import,"$Id: import.cpp 1191 2007-12-10 01:58:46Z dooglus $");
+SYNFIG_LAYER_SET_CVS_ID(Import,"$Id$");
 
 /* === P R O C E D U R E S ================================================= */
 
@@ -162,7 +162,7 @@ Import::set_param(const String & param, const ValueBase &value)
 		}
 
 		surface.clear();
-		if(!newimporter->get_frame(surface,Time(0)))
+		if(!newimporter->get_frame(surface,Time(0),trimmed,width,height,top,left))
 		{
 			synfig::warning(strprintf("Unable to get frame from \"%s\"",filename_with_path.c_str()));
 		}
@@ -220,15 +220,19 @@ Import::get_param_vocab()const
 void
 Import::set_time(Context context, Time time)const
 {
-	if(get_amount() && importer && importer->is_animated())importer->get_frame(surface,time+time_offset);
-	//else surface.clear();
+	if(get_amount() && importer &&
+	   importer->is_animated())
+		importer->get_frame(surface,time+time_offset,trimmed,width,height,top,left);
+
 	context.set_time(time);
 }
 
 void
 Import::set_time(Context context, Time time, const Point &pos)const
 {
-	if(get_amount() && importer && importer->is_animated())importer->get_frame(surface,time+time_offset);
-	//else surface.clear();
+	if(get_amount() && importer &&
+	   importer->is_animated())
+		importer->get_frame(surface,time+time_offset,trimmed,width,height,top,left);
+
 	context.set_time(time,pos);
 }
