@@ -2,7 +2,7 @@
 /*!	\file layer_bitmap.h
 **	\brief Template Header
 **
-**	$Id: layer_bitmap.h 335 2007-03-16 00:39:09Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -43,7 +43,7 @@ namespace synfig {
 */
 class Layer_Bitmap : public Layer_Composite, public Layer_NoDeform
 {
-	const Color& filter(const Color& c)const;
+	const Color& filter(Color& c)const;
 public:
 	typedef etl::handle<Layer_Bitmap> Handle;
 
@@ -51,6 +51,8 @@ public:
 	Point br;
 	int c;
 	mutable Surface surface;
+	mutable bool trimmed;
+	mutable unsigned int width, height, top, left;
 
 	Real gamma_adjust;
 
