@@ -8,6 +8,7 @@
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
 **	Copyright (c) 2009 Carlos A. Sosa Navarro
+**	Copyright (c) 2009 Nikita Kitaev
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -1340,8 +1341,8 @@ CanvasParser::parse_linkable_value_node(xmlpp::Element *element,Canvas::Handle c
 		if (version == "0.1" || version == "0.2" || version == "0.3")
 		{
 			handle<LinkableValueNode> scale_value_node=LinkableValueNode::create("scale",type);
-			scale_value_node->set_link(scale_value_node->get_link_index_from_name("link"), value_node);
-			scale_value_node->set_link(scale_value_node->get_link_index_from_name("scalar"), ValueNode_Const::create(Real(0.5)));
+			scale_value_node->set_link("link", value_node);
+			scale_value_node->set_link("scalar", ValueNode_Const::create(Real(0.5)));
 			value_node = scale_value_node;
 		}
 	}
