@@ -6,6 +6,7 @@
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**  Copyright (c) 2010 Diego Barrios Romero
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -33,6 +34,7 @@
 #include "canvas.h"
 #include "target_null.h"
 #include "target_null_tile.h"
+#include "targetparam.h"
 
 using namespace synfig;
 using namespace etl;
@@ -54,9 +56,17 @@ Target::subsys_init()
 	default_gamma_=new synfig::Gamma(1.0/2.2);
 	//default_gamma_->set_black_level(0.05); // Default to 5% black level.
 
-	book()["null"]=std::pair<synfig::Target::Factory,String>(Target_Null::create,"null");
+	// At least one target must be available.
+	book()["null"].factory =
+		reinterpret_cast<synfig::Target::Factory>(&Target_Null::create);
+	book()["null"].filename = "null";
+	book()["null"].target_param = TargetParam();
 	ext_book()["null"]="null";
-	book()["null-tile"]=std::pair<synfig::Target::Factory,String>(Target_Null_Tile::create,"null-tile");
+
+	book()["null-tile"].factory =
+		reinterpret_cast<synfig::Target::Factory>(&Target_Null_Tile::create);
+	book()["null-tile"].filename = "null-tile";
+	book()["null-tile"].target_param = TargetParam();
 	ext_book()["null-tile"]="null-tile";
 
 	return true;
@@ -104,10 +114,11 @@ synfig::Target::set_canvas(etl::handle<Canvas> c)
 
 
 Target::Handle
-Target::create(const String &name, const String &filename)
+Target::create(const String &name, const String &filename,
+			   synfig::TargetParam params)
 {
 	if(!book().count(name))
 		return handle<Target>();
 
-	return Target::Handle(book()[name].first(filename.c_str()));
+	return Target::Handle(book()[name].factory(filename.c_str(), params));
 }
