@@ -6,6 +6,7 @@
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -40,6 +41,9 @@ class ValueNode_BLineCalcTangent : public LinkableValueNode
 	ValueNode::RHandle bline_;
 	ValueNode::RHandle loop_;
 	ValueNode::RHandle amount_;
+	ValueNode::RHandle offset_;
+	ValueNode::RHandle scale_;
+	ValueNode::RHandle fixed_length_;
 
 	ValueNode_BLineCalcTangent(const ValueBase::Type &x=ValueBase::TYPE_VECTOR);
 
@@ -48,6 +52,7 @@ public:
 	typedef etl::handle<ValueNode_BLineCalcTangent> Handle;
 	typedef etl::handle<const ValueNode_BLineCalcTangent> ConstHandle;
 
+	virtual ValueBase operator()(Time t, Real amount)const;
 	virtual ValueBase operator()(Time t)const;
 
 	virtual ~ValueNode_BLineCalcTangent();
