@@ -2,7 +2,7 @@
 /*!	\file valuenode_stripes.cpp
 **	\brief Implementation of the "Stripes" valuenode conversion.
 **
-**	$Id: valuenode_stripes.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id$
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -93,6 +93,9 @@ synfig::ValueNode_Stripes::~ValueNode_Stripes()
 synfig::ValueBase
 synfig::ValueNode_Stripes::operator()(Time t)const
 {
+	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
+		printf("%s:%d operator()\n", __FILE__, __LINE__);
+
 	const int total((*stripes_)(t).get(int()));
 	int i;
 	Gradient ret;
